import xlwt


class ReportFileUtils:
    def __init__(self):
        self.styleOK = xlwt.easyxf()
        self.default_style = self.set_style('Times New Roman',
                       200,
                       bold=False,
                       format_str='', align='')
    pass

    def set_style(self, name, height, bold=False, format_str='', align='center'):
        style = xlwt.XFStyle()  # 初始化样式

        font = xlwt.Font()  # 为样式创建字体
        font.name = name  # 'Times New Roman'
        font.bold = bold
        font.height = height

        borders = xlwt.Borders()  # 为样式创建边框
        borders.left = 2
        borders.right = 2
        borders.top = 0
        borders.bottom = 2

        alignment = xlwt.Alignment()  # 设置排列
        if align == 'center':
            alignment.horz = xlwt.Alignment.HORZ_CENTER
            alignment.vert = xlwt.Alignment.VERT_CENTER
        else:
            alignment.horz = xlwt.Alignment.HORZ_LEFT
            alignment.vert = xlwt.Alignment.VERT_BOTTOM

        style.font = font
        style.borders = borders
        style.num_format_str = format_str
        style.alignment = alignment

        return style

    def horizontal_cell_merge(self, ws, start_row, end_row, start_col, end_col, content):
        """
            横向单元格合并
        :param ws:
        :param start_row:
        :param end_row:
        :param start_col:
        :param end_col:
        :param content:
        :return:
        """
        ws.write_merge(
            start_row,
            end_row,
            start_col,
            end_col,
            content,
            self.set_style(
                'Times New Roman',
                320,
                bold=True,
                format_str=''))

    def horizontal_space_cells(self, ws, start_row, end_row, start_col, end_col):
        self.horizontal_cell_merge(ws, start_row, end_row, start_col, end_col, '')

    def vertical_cell_merge(self, ws, start_row, end_row, start_col, end_col, content):
        """
            纵向单元格合并
        :param ws:
        :param start_row:
        :param rows:
        :param start_col:
        :param end_col:
        :param content:
        :return:
        """
        ws.write_merge(
            start_row,
            end_row,
            start_col,
            end_col,
            content,
            self.set_style(
                'Times New Roman',
                320,
                bold=True,
                format_str=''))  # 合并单元格

    def insert_cells(self, ws, data, start_row, start_col, end_col):
        for index, v in enumerate(data):
            y = 0
            for col in range(start_col, end_col):
                value = v[y]
                if value is None:
                    value = 0
                ws.col(col).width = 150 * 30  # 定义列宽
                ws.write(start_row, col, str(value),
                         style=self.default_style)
                y += 1
            start_row += 1

    def horizontal_space_cells(self, ws, start_row, end_row, start_col, end_col):
        """
            空白占位
        :param ws:
        :param start_row:
        :param end_row:
        :param start_col:
        :param end_col:
        :return:
        """
        self.horizontal_cell_merge(ws, start_row, end_row, start_col, end_col, '')

    def create_excel_file(self, data, sheet_names, title, headers, file_path):
        """
            生成excel文件， data, sheet_names,headers 三者在数量上要对应
        :param data: 数据
        :param sheet_names: 工作簿名称
        :param title: 文件名称
        :param headers: 每个工作簿表头
        :return:
        """
        self.wb = xlwt.Workbook()
        for index, d in enumerate(data):
            # 创建工作簿
            sheet_name = sheet_names[index]
            header = headers[index]
            ws = self.wb.add_sheet(sheet_name, cell_overwrite_ok=True)
            # 区域
            start_row = 0
            # 写入标题
            # self.horizontal_cell_merge(ws, start_row, start_row, 0, len(header) - 1, sheet_name)
            # start_row += 1

            # 写入表头
            self.insert_cells(ws, [headers[index]], start_row, 0, len(header))
            # start_row += 1
            # city_info = {}
            # insert_data = []
            # region_info = {}
            # data_size = 0
            # for key in d.keys():
            #     region_rows = 0
            #     value = d.get(key)
            #     region_name = key
            #     # 城市
            #     for key_1 in value.keys():
            #         value_1 = value.get(key_1)
            #         city_name = key_1
            #         region_rows += len(value_1)
            #         insert_data.extend(value_1)
            #         city_info[city_name] = len(value_1)
            #         data_size = len(value_1[0])
            #     region_info[region_name] = region_rows
            # # 合并区域
            # for key in region_info.keys():
            #     print(key)
            #     self.vertical_cell_merge(ws, start_row, start_row + region_info.get(key) - 1, 0, 0, key)
            #     start_row += region_info.get(key)
            # # 城市合并
            # start_row = 2
            # for key in city_info.keys():
            #      self.vertical_cell_merge(ws, start_row, start_row + city_info.get(key) - 1, 1, 1, key)
            #      start_row += city_info.get(key)

            # 写入数据
            start_row = 1
            self.insert_cells(ws, d, start_row, 0, len(d[0]))
        self.wb.save(file_path)


if __name__ == '__main__':
    rf = ReportFileUtils()
    data_1 = dict(
        houseids=["10328", "10329", "10330", "10331", "10332", "10333", "10334", "10335", "10336", "10337", "10338",
                  "10339", "10340", "10341", "10342", "10343", "10344", "10345", "10346", "10347", "10348", "10349",
                  "10350", "10351", "10352", "10353", "10354", "10355", "10356", "10357", "10358", "10359", "10360",
                  "10361", "10362", "10363", "10364", "10366", "10367", "10368", "10369", "10370", "10371", "10372",
                  "10373", "10374", "10375", "10376", "10377", "10378", "10379", "10380", "10381", "10382", "10383",
                  "10384", "10385", "10386", "10387", "10388", "10389", "10390", "10391", "10392", "10393", "10394",
                  "10395", "10396", "10397", "10398", "10399", "10400", "10401", "10402", "10403", "10405", "10406",
                  "10407", "10408", "10409", "10410", "10411", "10412", "10414", "10415", "10416", "10417", "10418",
                  "10419", "10420", "10421", "10422", "10424", "10425", "10473", "10474", "10476", "10500", "10502",
                  "10503", "10504", "10505", "10506", "10507", "10509", "10510", "10511", "10514", "10515", "10517",
                  "10518", "10519", "10520", "10521", "10522", "10523", "10524", "10525", "10527", "10528", "10529",
                  "10532", "10533", "10535", "10537", "10538", "10539", "10551", "10554", "10555", "10151", "10165",
                  "10166", "10167", "10168", "10169", "10170", "10171", "10172", "10173", "10174", "10175", "10315",
                  "10316", "10317", "10318", "10319", "10320", "10321", "10322", "10323", "10324", "10325"],
        data1=[67155.0, 8003, 5498, 4376, 4607, 0, 0, 0, 0, 0, 0, 0, 825870.0, 71548, 0, 0, 4607, 0, 0, 0, 7142, 0, 0,
               0, 2573232.0, 192630, 178277, 116077, 4607, 0, 0, 0, 17641, 0, 0, 0], data2=[
            [["新乡", "新乡建业世和府", 13383.0, 727, 306, 221, 286, 0, 0, 0, 0, 0, 0, 0],
             ["驻马店", "驻马店建业春天里", 3994.0, 330, 238, 204, 378, 0, 0, 0, 0, 0, 0, 0],
             ["周口", "鹿邑建业城", 3613.0, 263, 231, 172, 643, 0, 0, 0, 0, 0, 0, 0],
             ["周口", "西华建业箕城上院", 2843.0, 348, 276, 250, 366, 0, 0, 0, 0, 0, 0, 0],
             ["驻马店", "汝南建业城", 2422.0, 316, 176, 136, 380, 0, 0, 0, 0, 0, 0, 0],
             ["周口", "太康建业幸福里", 1702.0, 199, 156, 119, 412, 0, 0, 0, 0, 0, 0, 0],
             ["周口", "周口建业城", 1694.0, 325, 259, 179, 246, 0, 0, 0, 0, 0, 0, 0],
             ["漯河", "漯河建业桂园", 1456.0, 105, 89, 86, 211, 0, 0, 0, 0, 0, 0, 0],
             ["南阳", "邓州建业公园里", 1340.0, 312, 227, 152, 206, 0, 0, 0, 0, 0, 0, 0],
             ["商丘", "虞城建业山水湖城", 1299.0, 197, 155, 128, 180, 0, 0, 0, 0, 0, 0, 0],
             ["信阳", "固始建业未来城", 1233.0, 226, 201, 182, 189, 0, 0, 0, 0, 0, 0, 0],
             ["周口", "扶沟建业新城", 1076.0, 347, 301, 263, 408, 0, 0, 0, 0, 0, 0, 0],
             ["驻马店", "驻马店建业尊府", 1020.0, 123, 87, 77, 240, 0, 0, 0, 0, 0, 0, 0],
             ["驻马店", "西平建业春天里", 955.0, 80, 66, 52, 164, 0, 0, 0, 0, 0, 0, 0],
             ["南阳", "南阳建业新筑", 950.0, 152, 107, 78, 85, 0, 0, 0, 0, 0, 0, 0],
             ["洛阳", "洛阳建业定鼎府", 940.0, 254, 212, 174, 190, 0, 0, 0, 0, 0, 0, 0],
             ["驻马店", "驻马店建业世和府", 905.0, 175, 91, 82, 111, 0, 0, 0, 0, 0, 0, 0],
             ["周口", "周口建业世和府", 858.0, 145, 91, 68, 79, 0, 0, 0, 0, 0, 0, 0],
             ["南阳", "南召建业城", 843.0, 113, 82, 70, 69, 0, 0, 0, 0, 0, 0, 0],
             ["驻马店", "驻马店正阳建业城", 824.0, 94, 54, 48, 65, 0, 0, 0, 0, 0, 0, 0],
             ["济源", "济源建业城", 779.0, 73, 35, 16, 4, 0, 0, 0, 0, 0, 0, 0],
             ["郑州", "郑州建业橙园", 756.0, 141, 63, 46, 34, 0, 0, 0, 0, 0, 0, 0],
             ["开封", "杞县建业一品花园里", 751.0, 75, 29, 23, 66, 0, 0, 0, 0, 0, 0, 0],
             ["周口", "周口建业世悦府", 749.0, 86, 45, 34, 48, 0, 0, 0, 0, 0, 0, 0],
             ["周口", "周口建业大城小院", 738.0, 126, 80, 61, 74, 0, 0, 0, 0, 0, 0, 0],
             ["周口", "周口建业山水湖城", 717.0, 325, 307, 262, 301, 0, 0, 0, 0, 0, 0, 0],
             ["洛阳", "洛阳建业贰号城邦", 713.0, 14, 8, 3, 4, 0, 0, 0, 0, 0, 0, 0],
             ["周口", "商水建业阳城上院", 670.0, 80, 65, 43, 138, 0, 0, 0, 0, 0, 0, 0],
             ["信阳", "淮滨建业桂园", 667.0, 74, 53, 52, 180, 0, 0, 0, 0, 0, 0, 0],
             ["新乡", "辉县建业共城东望", 657.0, 84, 51, 52, 44, 0, 0, 0, 0, 0, 0, 0],
             ["周口", "鹿邑明道城", 653.0, 71, 58, 47, 174, 0, 0, 0, 0, 0, 0, 0],
             ["周口", "项城建业城", 585.0, 68, 39, 30, 38, 0, 0, 0, 0, 0, 0, 0],
             ["驻马店", "平舆建业公园里", 559.0, 186, 128, 117, 161, 0, 0, 0, 0, 0, 0, 0],
             ["信阳", "息县建业尊府", 526.0, 174, 135, 117, 142, 0, 0, 0, 0, 0, 0, 0],
             ["鹤壁", "鹤壁建业臻悦汇", 524.0, 32, 19, 17, 16, 0, 0, 0, 0, 0, 0, 0],
             ["新乡", "卫辉建业春天里", 520.0, 80, 56, 45, 62, 0, 0, 0, 0, 0, 0, 0],
             ["商丘", "商丘建业橙园", 519.0, 80, 28, 19, 26, 0, 0, 0, 0, 0, 0, 0],
             ["郑州", "建业J18", 491.0, 89, 60, 34, 60, 0, 0, 0, 0, 0, 0, 0],
             ["郑州", "郑州建业比华利庄园", 463.0, 44, 21, 17, 12, 0, 0, 0, 0, 0, 0, 0],
             ["驻马店", "驻马店建业凯旋广场", 448.0, 86, 58, 47, 58, 0, 0, 0, 0, 0, 0, 0],
             ["漯河", "漯河建业花园里", 446.0, 54, 31, 26, 66, 0, 0, 0, 0, 0, 0, 0],
             ["南阳", "南阳建业碧桂园龙悦城", 405.0, 77, 43, 40, 23, 0, 0, 0, 0, 0, 0, 0],
             ["三门峡", "三门峡建业新区森林半岛", 393.0, 34, 11, 9, 8, 0, 0, 0, 0, 0, 0, 0],
             ["周口", "太康建业生态新城", 379.0, 60, 10, 10, 15, 0, 0, 0, 0, 0, 0, 0],
             ["三门峡", "三门峡建业尊府", 373.0, 30, 18, 17, 14, 0, 0, 0, 0, 0, 0, 0],
             ["安阳", "安阳建业世和府", 367.0, 30, 18, 13, 13, 0, 0, 0, 0, 0, 0, 0],
             ["驻马店", "遂平建业城", 340.0, 60, 34, 30, 28, 0, 0, 0, 0, 0, 0, 0],
             ["安阳", "安阳建业通和府", 331.0, 58, 15, 15, 7, 0, 0, 0, 0, 0, 0, 0],
             ["三门峡", "三门峡建业城", 329.0, 39, 21, 19, 18, 0, 0, 0, 0, 0, 0, 0],
             ["新乡", "新乡建业春天里", 327.0, 40, 21, 19, 20, 0, 0, 0, 0, 0, 0, 0],
             ["焦作", "焦作建业春天里", 319.0, 32, 16, 16, 7, 0, 0, 0, 0, 0, 0, 0],
             ["信阳", "潢川建业黄国府", 316.0, 69, 49, 35, 62, 0, 0, 0, 0, 0, 0, 0],
             ["洛阳", "洛阳建业滨河珑府", 314.0, 26, 14, 10, 2, 0, 0, 0, 0, 0, 0, 0],
             ["信阳", "信阳建业城云熙府", 296.0, 72, 32, 23, 22, 0, 0, 0, 0, 0, 0, 0],
             ["周口", "淮阳建业百城天地", 293.0, 61, 11, 9, 9, 0, 0, 0, 0, 0, 0, 0],
             ["焦作", "博爱建业春天里", 284.0, 38, 29, 27, 26, 0, 0, 0, 0, 0, 0, 0],
             ["漯河", "漯河建业云熙府", 268.0, 66, 37, 30, 40, 0, 0, 0, 0, 0, 0, 0],
             ["南阳", "西峡建业公园里", 266.0, 45, 38, 37, 2, 0, 0, 0, 0, 0, 0, 0],
             ["洛阳", "栾川建业鸾州府", 261.0, 35, 24, 15, 3, 0, 0, 0, 0, 0, 0, 0],
             ["南阳", "南阳建业公园里", 252.0, 68, 21, 14, 13, 0, 0, 0, 0, 0, 0, 0],
             ["周口", "西华建业公园里", 245.0, 76, 54, 46, 51, 0, 0, 0, 0, 0, 0, 0],
             ["洛阳", "伊川建业龙府", 237.0, 17, 11, 8, 2, 0, 0, 0, 0, 0, 0, 0],
             ["南阳", "南阳建业十里湖山", 225.0, 60, 29, 29, 22, 0, 0, 0, 0, 0, 0, 0],
             ["信阳", "建业信阳府", 224.0, 24, 16, 11, 11, 0, 0, 0, 0, 0, 0, 0],
             ["商丘", "商丘建业花园里", 223.0, 35, 23, 19, 13, 0, 0, 0, 0, 0, 0, 0],
             ["洛阳", "洛阳建业大城小院", 196.0, 13, 6, 3, 2, 0, 0, 0, 0, 0, 0, 0],
             ["鹤壁", "鹤壁建业世和府", 189.0, 23, 11, 12, 4, 0, 0, 0, 0, 0, 0, 0],
             ["郑州", "郑州建业新筑", 185.0, 37, 17, 17, 5, 0, 0, 0, 0, 0, 0, 0],
             ["信阳", "固始建业城", 177.0, 43, 25, 25, 18, 0, 0, 0, 0, 0, 0, 0],
             ["开封", "开封建业花园里", 175.0, 25, 6, 4, 2, 0, 0, 0, 0, 0, 0, 0],
             ["漯河", "临颍建业森林半岛", 173.0, 30, 20, 16, 41, 0, 0, 0, 0, 0, 0, 0],
             ["商丘", "商丘建业天筑", 160.0, 6, 5, 5, 0, 0, 0, 0, 0, 0, 0, 0],
             ["郑州", "登封建业嵩岳府", 157.0, 29, 11, 10, 8, 0, 0, 0, 0, 0, 0, 0],
             ["郑州", "郑西建业联盟新城", 140.0, 32, 17, 12, 13, 0, 0, 0, 0, 0, 0, 0],
             ["许昌", "许昌建业世和府", 129.0, 7, 5, 3, 1, 0, 0, 0, 0, 0, 0, 0],
             ["焦作", "焦作建业世和府", 129.0, 22, 6, 3, 1, 0, 0, 0, 0, 0, 0, 0],
             ["商丘", "商丘建业十八城山水上境", 124.0, 22, 12, 9, 2, 0, 0, 0, 0, 0, 0, 0],
             ["郑州", "郑州建业云境", 114.0, 20, 12, 10, 1, 0, 0, 0, 0, 0, 0, 0],
             ["商丘", "睢县建业上和院", 102.0, 27, 10, 9, 8, 0, 0, 0, 0, 0, 0, 0],
             ["济源", "济源建业春天里", 96.0, 14, 9, 8, 3, 0, 0, 0, 0, 0, 0, 0],
             ["洛阳", "洛阳建业龙城东望", 94.0, 15, 6, 5, 2, 0, 0, 0, 0, 0, 0, 0],
             ["新乡", "新乡建业联盟新城", 81.0, 10, 5, 5, 2, 0, 0, 0, 0, 0, 0, 0],
             ["开封", "通许建业壹号城邦", 70.0, 31, 18, 12, 14, 0, 0, 0, 0, 0, 0, 0],
             ["新乡", "新乡建业花园里", 68.0, 24, 13, 7, 9, 0, 0, 0, 0, 0, 0, 0],
             ["濮阳", "濮阳建业世和府", 68.0, 13, 5, 6, 4, 0, 0, 0, 0, 0, 0, 0],
             ["驻马店", "西平建业森林半岛", 64.0, 10, 10, 9, 4, 0, 0, 0, 0, 0, 0, 0],
             ["平顶山", "平顶山建业春天里", 58.0, 16, 4, 7, 1, 0, 0, 0, 0, 0, 0, 0],
             ["郑州", "新密建业春天里", 55.0, 6, 6, 5, 0, 0, 0, 0, 0, 0, 0, 0],
             ["焦作", "温县建业春天里", 51.0, 14, 7, 5, 10, 0, 0, 0, 0, 0, 0, 0],
             ["许昌", "许昌建业臻悦汇", 49.0, 6, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0],
             ["郑州", "新郑建业天汇城", 49.0, 17, 13, 13, 0, 0, 0, 0, 0, 0, 0, 0],
             ["安阳", "安阳建业城", 47.0, 5, 5, 4, 0, 0, 0, 0, 0, 0, 0, 0],
             ["许昌", "许昌建业心怡苑", 45.0, 19, 9, 4, 9, 0, 0, 0, 0, 0, 0, 0],
             ["开封", "通许建业城", 38.0, 14, 14, 9, 10, 0, 0, 0, 0, 0, 0, 0],
             ["许昌", "禹州建业春天里", 35.0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0],
             ["许昌", "禹州建业大城小院", 32.0, 5, 4, 3, 0, 0, 0, 0, 0, 0, 0, 0],
             ["郑州", "郑州建业凯旋广场", 32.0, 11, 10, 8, 0, 0, 0, 0, 0, 0, 0, 0],
             ["周口", "太康建业城", 32.0, 4, 3, 4, 0, 0, 0, 0, 0, 0, 0, 0],
             ["商丘", "商丘建业新筑", 31.0, 3, 3, 2, 0, 0, 0, 0, 0, 0, 0, 0],
             ["漯河", "漯河建业丹江府", 30.0, 7, 4, 3, 5, 0, 0, 0, 0, 0, 0, 0],
             ["平顶山", "平顶山建业光明府", 29.0, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0],
             ["濮阳", "濮阳建业龙城", 29.0, 7, 4, 3, 2, 0, 0, 0, 0, 0, 0, 0],
             ["平顶山", "汝州建业桂园", 28.0, 4, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0],
             ["郑州", "郑州建业昌建公园里", 28.0, 13, 10, 11, 4, 0, 0, 0, 0, 0, 0, 0],
             ["许昌", "鄢陵建业生态新城", 26.0, 3, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0],
             ["安阳", "汤阴建业公园里", 25.0, 5, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0],
             ["开封", "开封建业半亩园", 22.0, 4, 4, 4, 2, 0, 0, 0, 0, 0, 0, 0],
             ["驻马店", "新蔡建百城天地", 20.0, 5, 3, 3, 1, 0, 0, 0, 0, 0, 0, 0],
             ["商丘", "民权建业天明幸福里", 17.0, 13, 11, 10, 6, 0, 0, 0, 0, 0, 0, 0],
             ["商丘", "商丘建业信友未来城", 15.0, 3, 3, 2, 0, 0, 0, 0, 0, 0, 0, 0],
             ["郑州", "巩义建业世和府", 15.0, 6, 3, 4, 0, 0, 0, 0, 0, 0, 0, 0],
             ["驻马店", "平舆建业城", 12.0, 6, 6, 6, 0, 0, 0, 0, 0, 0, 0, 0],
             ["驻马店", "驻马店建业西湖庄园", 11.0, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0],
             ["驻马店", "新蔡建业桂园", 11.0, 6, 4, 4, 0, 0, 0, 0, 0, 0, 0, 0],
             ["平顶山", "舞钢建业森林半岛", 8.0, 7, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0],
             ["开封", "兰考建业红天地", 8.0, 4, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0],
             ["驻马店", "遂平建业森林半岛", 7.0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0],
             ["郑州", "郑州建业尚悦广场", 6.0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0],
             ["许昌", "长葛建业森林半岛", 4.0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["新乡", "辉县建业壹号城邦", 4.0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0],
             ["三门峡", "三门峡建业联盟新城", 3.0, 2, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0],
             ["濮阳", "濮阳建业臻悦汇", 2.0, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0],
             ["许昌", "襄城建业百城天地", 1.0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0],
             ["许昌", "长葛建业桂园新苑", 1.0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0],
             ["洛阳", "洛阳建业科技城", 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0],
             ["洛阳", "洛阳建业中州府 ", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], ["洛阳", "建业尊府", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["平顶山", "平顶山建业十八城", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["洛阳", "偃师建业森林半岛", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["商丘", "商丘建业幸福里", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], ["商丘", "夏邑建业城", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["商丘", "商丘建业公园里", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["济源", "济源建业花园里", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["焦作", "武陟建业星天地", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["新乡", "长垣建业森林半岛上院", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["郑州", "郑州建业天筑", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["郑州", "新郑建业重点项目", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["鹤壁", "鹤壁建业桂园", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["鹤壁", "滑县建业壹号城邦", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["新乡", "辉县建业春天里", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["济源", "济源壹号城邦天玺", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["洛阳", "洛阳建业桂园", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], ["洛阳", "洛阳建业尊府", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["漯河", "漯河建业壹号城邦", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["三门峡", "三门峡建业壹号城邦", 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["商丘", "永城建业联盟新城", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["郑州", "郑州建业盛悦府", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["郑州", "郑州建业五龙新城", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["濮阳", "濮阳建业壹号城邦", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["安阳", "林州建业城", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["安阳", "安阳建业君邻大院", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["平顶山", "平顶山建业平西尊府", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["驻马店", "驻马店建业滨河珑府", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]],
            [["新乡", "新乡建业世和府", 70183.0, 3304, 0, 0, 286, 836, 8, 0, 100, 0, 676, 0],
             ["驻马店", "遂平建业城", 40140.0, 3946, 0, 0, 28, 3106, 10, 6, 1068, 0, 129, 0],
             ["驻马店", "汝南建业城", 32448.0, 1845, 0, 0, 380, 1305, 19, 6, 24, 0, 189, 0],
             ["济源", "济源建业城", 21625.0, 3197, 0, 0, 4, 105, 0, 0, 1, 0, 10, 0],
             ["周口", "西华建业箕城上院", 19861.0, 2218, 0, 0, 366, 1355, 1, 7, 398, 0, 148, 0],
             ["周口", "太康建业幸福里", 18896.0, 1681, 0, 0, 412, 916, 5, 53, 21, 0, 93, 0],
             ["周口", "鹿邑建业城", 18082.0, 1205, 0, 0, 643, 567, 0, 8, 1, 0, 27, 0],
             ["漯河", "漯河建业桂园", 18036.0, 1266, 0, 0, 211, 838, 1, 12, 27, 0, 85, 0],
             ["漯河", "漯河建业花园里", 17411.0, 1376, 0, 0, 66, 925, 1, 13, 89, 0, 89, 0],
             ["驻马店", "西平建业春天里", 16483.0, 1099, 0, 0, 164, 634, 2, 17, 34, 0, 79, 4],
             ["信阳", "息县建业尊府", 15874.0, 1962, 0, 0, 142, 1220, 9, 0, 234, 0, 329, 0],
             ["开封", "杞县建业一品花园里", 15258.0, 769, 0, 0, 66, 402, 0, 2, 77, 0, 87, 0],
             ["周口", "周口建业世悦府", 13985.0, 2194, 0, 0, 48, 1271, 2, 14, 63, 0, 172, 0],
             ["驻马店", "驻马店正阳建业城", 13463.0, 1430, 0, 0, 65, 844, 80, 10, 234, 0, 567, 0],
             ["新乡", "辉县建业共城东望", 13426.0, 1559, 0, 0, 44, 784, 0, 17, 206, 0, 125, 0],
             ["驻马店", "驻马店建业尊府", 13379.0, 1068, 0, 0, 240, 693, 0, 0, 32, 0, 130, 0],
             ["驻马店", "驻马店建业春天里", 13236.0, 1081, 0, 0, 378, 160, 1, 75, 78, 0, 422, 0],
             ["周口", "太康建业生态新城", 13178.0, 1491, 0, 0, 15, 907, 0, 16, 3, 0, 554, 0],
             ["周口", "周口建业城", 12832.0, 1416, 0, 0, 246, 742, 33, 2, 2, 0, 0, 0],
             ["周口", "扶沟建业新城", 11961.0, 2162, 0, 0, 408, 1126, 4, 2, 109, 1, 268, 0],
             ["周口", "周口建业世和府", 11653.0, 2032, 0, 0, 79, 1275, 1, 5, 13, 0, 233, 0],
             ["开封", "开封建业花园里", 11552.0, 503, 0, 0, 2, 275, 0, 3, 100, 0, 222, 0],
             ["洛阳", "洛阳建业定鼎府", 11227.0, 1260, 0, 0, 190, 232, 23, 63, 4, 0, 107, 0],
             ["鹤壁", "鹤壁建业臻悦汇", 11093.0, 495, 0, 0, 16, 193, 3, 1, 63, 0, 98, 0],
             ["驻马店", "平舆建业公园里", 10940.0, 1621, 0, 0, 161, 1069, 11, 11, 100, 0, 294, 0],
             ["驻马店", "驻马店建业世和府", 10746.0, 1179, 0, 0, 111, 412, 9, 2, 108, 0, 443, 0],
             ["焦作", "温县建业春天里", 10400.0, 1004, 0, 0, 10, 440, 2, 4, 25, 0, 265, 1],
             ["信阳", "潢川建业黄国府", 10397.0, 1411, 0, 0, 62, 606, 21, 0, 1, 0, 72, 0],
             ["郑州", "郑州建业橙园", 9745.0, 1198, 0, 0, 34, 86, 1, 2, 2, 0, 99, 0],
             ["安阳", "安阳建业通和府", 9704.0, 697, 0, 0, 7, 292, 3, 192, 136, 0, 643, 91],
             ["信阳", "淮滨建业桂园", 9655.0, 870, 0, 0, 180, 520, 1, 2, 98, 0, 78, 1],
             ["新乡", "卫辉建业春天里", 9629.0, 1037, 0, 0, 62, 461, 2, 0, 97, 0, 155, 0],
             ["周口", "周口建业大城小院", 9537.0, 1040, 0, 0, 74, 585, 1, 2, 2, 0, 64, 1],
             ["周口", "鹿邑明道城", 9095.0, 712, 0, 0, 174, 365, 16, 0, 3, 0, 99, 0],
             ["驻马店", "驻马店建业凯旋广场", 8941.0, 1265, 0, 0, 58, 731, 0, 2, 6, 0, 105, 0],
             ["郑州", "郑州建业比华利庄园", 8709.0, 855, 0, 0, 12, 184, 3, 0, 5, 0, 86, 0],
             ["周口", "商水建业阳城上院", 8539.0, 693, 0, 0, 138, 317, 0, 2, 47, 0, 23, 0],
             ["南阳", "邓州建业公园里", 8358.0, 1526, 0, 0, 206, 695, 9, 131, 46, 0, 313, 18],
             ["郑州", "郑西建业联盟新城", 7928.0, 1465, 0, 0, 13, 759, 29, 0, 40, 0, 179, 0],
             ["安阳", "安阳建业世和府", 7800.0, 445, 0, 0, 13, 126, 0, 1, 16, 0, 108, 0],
             ["郑州", "郑州建业新筑", 7423.0, 1465, 0, 0, 5, 426, 1, 0, 2, 0, 39, 0],
             ["周口", "周口建业山水湖城", 7188.0, 1799, 0, 0, 301, 989, 68, 0, 41, 0, 55, 0],
             ["信阳", "建业信阳府", 6787.0, 554, 0, 0, 11, 228, 0, 0, 3, 0, 46, 0],
             ["漯河", "漯河建业云熙府", 6166.0, 1017, 0, 0, 40, 471, 1, 1, 48, 0, 75, 0],
             ["商丘", "睢县建业上和院", 5931.0, 575, 0, 0, 8, 264, 1, 3, 25, 0, 84, 0],
             ["商丘", "商丘建业橙园", 5505.0, 444, 0, 0, 26, 66, 0, 32, 34, 0, 391, 0],
             ["新乡", "新乡建业春天里", 5479.0, 368, 0, 0, 20, 133, 2, 0, 75, 0, 220, 0],
             ["周口", "项城建业城", 5373.0, 474, 0, 0, 38, 143, 11, 0, 12, 0, 150, 0],
             ["焦作", "焦作建业春天里", 5272.0, 760, 0, 0, 7, 358, 12, 0, 118, 0, 305, 0],
             ["南阳", "南阳建业碧桂园龙悦城", 5076.0, 844, 0, 0, 23, 271, 1, 45, 75, 0, 95, 0],
             ["三门峡", "三门峡建业城", 5056.0, 365, 0, 0, 18, 122, 5, 7, 10, 0, 41, 0],
             ["周口", "淮阳建业百城天地", 5051.0, 409, 0, 0, 9, 42, 0, 17, 0, 0, 3862, 0],
             ["周口", "西华建业公园里", 4956.0, 729, 0, 0, 51, 436, 11, 2, 0, 0, 71, 0],
             ["洛阳", "洛阳建业大城小院", 4850.0, 266, 0, 0, 2, 49, 5, 2, 0, 0, 37, 0],
             ["三门峡", "三门峡建业尊府", 4827.0, 283, 0, 0, 14, 107, 0, 0, 0, 0, 11, 0],
             ["三门峡", "三门峡建业新区森林半岛", 4768.0, 401, 0, 0, 8, 84, 0, 0, 4, 0, 32, 0],
             ["濮阳", "濮阳建业世和府", 4763.0, 278, 0, 0, 4, 68, 0, 3, 3, 0, 19, 0],
             ["信阳", "信阳建业城云熙府", 4726.0, 721, 0, 0, 22, 229, 6, 0, 30, 0, 185, 0],
             ["南阳", "南召建业城", 4715.0, 384, 0, 0, 69, 91, 0, 1, 12, 0, 128, 0],
             ["商丘", "虞城建业山水湖城", 4348.0, 481, 0, 0, 180, 87, 0, 20, 42, 0, 151, 0],
             ["郑州", "登封建业嵩岳府", 4314.0, 466, 0, 0, 8, 65, 0, 0, 0, 0, 11, 0],
             ["焦作", "博爱建业春天里", 4265.0, 555, 0, 0, 26, 322, 1, 0, 63, 0, 80, 0],
             ["信阳", "固始建业未来城", 4101.0, 584, 0, 0, 189, 255, 15, 0, 157, 0, 179, 0],
             ["漯河", "临颍建业森林半岛", 4071.0, 676, 0, 0, 41, 399, 0, 0, 0, 0, 485, 0],
             ["商丘", "民权建业天明幸福里", 3918.0, 334, 0, 0, 6, 70, 1, 6, 2, 0, 53, 0],
             ["济源", "济源建业春天里", 3793.0, 333, 0, 0, 3, 61, 0, 0, 0, 0, 1, 0],
             ["濮阳", "濮阳建业龙城", 3639.0, 330, 0, 0, 2, 117, 0, 0, 0, 0, 0, 0],
             ["商丘", "商丘建业十八城山水上境", 3593.0, 398, 0, 0, 2, 43, 2, 19, 24, 0, 153, 0],
             ["信阳", "固始建业城", 3492.0, 529, 0, 0, 18, 240, 25, 0, 36, 0, 205, 0],
             ["洛阳", "洛阳建业滨河珑府", 3395.0, 352, 0, 0, 2, 24, 0, 0, 3, 0, 89, 0],
             ["漯河", "漯河建业丹江府", 3344.0, 332, 0, 0, 5, 151, 0, 1, 20, 0, 55, 0],
             ["商丘", "商丘建业花园里", 3189.0, 394, 0, 0, 13, 28, 0, 16, 2, 0, 93, 5],
             ["鹤壁", "鹤壁建业世和府", 3170.0, 285, 0, 0, 4, 33, 0, 127, 4, 0, 112, 8],
             ["平顶山", "平顶山建业春天里", 3082.0, 331, 0, 0, 1, 25, 0, 0, 8, 0, 28, 0],
             ["洛阳", "洛阳建业龙城东望", 3041.0, 221, 0, 0, 2, 22, 0, 1, 1, 0, 59, 0],
             ["南阳", "南阳建业新筑", 3020.0, 361, 0, 0, 85, 50, 0, 0, 4, 0, 224, 0],
             ["焦作", "焦作建业世和府", 2920.0, 378, 0, 0, 1, 72, 0, 0, 16, 0, 144, 0],
             ["新乡", "新乡建业花园里", 2630.0, 290, 0, 0, 9, 79, 2, 4, 3, 0, 85, 0],
             ["南阳", "西峡建业公园里", 2528.0, 290, 0, 0, 2, 58, 0, 0, 4, 0, 92, 0],
             ["许昌", "许昌建业心怡苑", 2424.0, 198, 0, 0, 9, 53, 0, 0, 1, 0, 1, 0],
             ["郑州", "建业J18", 2380.0, 392, 0, 0, 60, 59, 2, 0, 0, 0, 28, 0],
             ["开封", "开封建业半亩园", 2318.0, 433, 0, 0, 2, 193, 40, 0, 10, 0, 147, 0],
             ["新乡", "新乡建业联盟新城", 2172.0, 180, 0, 0, 2, 18, 0, 0, 0, 0, 25, 0],
             ["郑州", "郑州建业云境", 2123.0, 309, 0, 0, 1, 37, 1, 0, 0, 0, 43, 0],
             ["洛阳", "栾川建业鸾州府", 2071.0, 235, 0, 0, 3, 12, 0, 0, 0, 0, 6, 0],
             ["洛阳", "洛阳建业贰号城邦", 1945.0, 177, 0, 0, 4, 9, 0, 0, 1, 0, 6, 0],
             ["许昌", "许昌建业臻悦汇", 1883.0, 110, 0, 0, 0, 21, 0, 0, 2, 0, 8, 0],
             ["商丘", "商丘建业天筑", 1802.0, 141, 0, 0, 0, 24, 0, 0, 0, 0, 19, 0],
             ["商丘", "商丘建业新筑", 1789.0, 139, 0, 0, 0, 6, 0, 0, 0, 0, 4, 0],
             ["许昌", "鄢陵建业生态新城", 1655.0, 80, 0, 0, 1, 17, 0, 0, 11, 0, 10, 0],
             ["郑州", "郑州建业昌建公园里", 1610.0, 285, 0, 0, 4, 8, 0, 0, 0, 0, 9, 0],
             ["洛阳", "伊川建业龙府", 1557.0, 160, 0, 0, 2, 11, 0, 0, 0, 0, 6, 0],
             ["许昌", "许昌建业世和府", 1427.0, 94, 0, 0, 1, 15, 0, 0, 1, 0, 6, 0],
             ["南阳", "南阳建业十里湖山", 1399.0, 277, 0, 0, 22, 56, 0, 0, 0, 0, 83, 0],
             ["安阳", "汤阴建业公园里", 1336.0, 135, 0, 0, 0, 21, 0, 0, 0, 0, 135, 0],
             ["平顶山", "汝州建业桂园", 1329.0, 162, 0, 0, 1, 22, 0, 24, 6, 0, 22, 0],
             ["开封", "兰考建业红天地", 1184.0, 140, 0, 0, 0, 33, 0, 0, 1, 0, 30, 0],
             ["安阳", "安阳建业城", 1145.0, 175, 0, 0, 0, 30, 1, 0, 0, 0, 1, 0],
             ["南阳", "南阳建业公园里", 1107.0, 258, 0, 0, 13, 19, 0, 0, 1, 0, 28, 0],
             ["开封", "通许建业壹号城邦", 952.0, 142, 0, 0, 14, 15, 0, 10, 0, 0, 47, 1],
             ["驻马店", "平舆建业城", 883.0, 111, 0, 0, 0, 22, 2, 1, 0, 0, 25, 0],
             ["许昌", "长葛建业森林半岛", 845.0, 110, 0, 0, 0, 20, 0, 0, 0, 0, 5, 0],
             ["驻马店", "遂平建业森林半岛", 727.0, 72, 0, 0, 0, 2, 0, 0, 0, 0, 1, 0],
             ["许昌", "禹州建业大城小院", 704.0, 76, 0, 0, 0, 12, 0, 0, 0, 0, 0, 0],
             ["许昌", "襄城建业百城天地", 701.0, 51, 0, 0, 0, 4, 0, 0, 0, 0, 3, 0],
             ["郑州", "郑州建业凯旋广场", 674.0, 111, 0, 0, 0, 9, 0, 0, 0, 0, 8, 0],
             ["郑州", "巩义建业世和府", 646.0, 135, 0, 0, 0, 5, 0, 0, 0, 0, 8, 0],
             ["平顶山", "平顶山建业光明府", 576.0, 51, 0, 0, 0, 5, 0, 0, 0, 0, 4, 0],
             ["商丘", "商丘建业信友未来城", 561.0, 57, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0],
             ["平顶山", "舞钢建业森林半岛", 537.0, 154, 0, 0, 0, 35, 0, 1, 1, 0, 44, 0],
             ["安阳", "安阳建业君邻大院", 496.0, 56, 0, 0, 0, 13, 0, 0, 0, 0, 0, 0],
             ["郑州", "新郑建业天汇城", 484.0, 147, 0, 0, 0, 10, 0, 0, 0, 0, 8, 0],
             ["许昌", "禹州建业春天里", 448.0, 58, 0, 0, 0, 3, 0, 0, 0, 0, 2, 0],
             ["驻马店", "西平建业森林半岛", 430.0, 52, 0, 0, 4, 3, 0, 0, 0, 0, 2, 0],
             ["驻马店", "新蔡建业桂园", 381.0, 45, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0],
             ["许昌", "长葛建业桂园新苑", 380.0, 49, 0, 0, 0, 2, 0, 0, 0, 0, 1, 0],
             ["郑州", "新密建业春天里", 363.0, 72, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0],
             ["开封", "通许建业城", 321.0, 62, 0, 0, 10, 4, 0, 0, 0, 0, 3, 0],
             ["驻马店", "新蔡建百城天地", 296.0, 44, 0, 0, 1, 9, 0, 0, 0, 0, 3, 0],
             ["郑州", "郑州建业盛悦府", 192.0, 25, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0],
             ["周口", "太康建业城", 174.0, 71, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0],
             ["驻马店", "驻马店建业西湖庄园", 108.0, 30, 0, 0, 1, 4, 0, 0, 0, 0, 12, 0],
             ["郑州", "郑州建业尚悦广场", 52.0, 37, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["濮阳", "濮阳建业臻悦汇", 42.0, 28, 0, 0, 0, 0, 0, 0, 0, 0, 9, 0],
             ["平顶山", "平顶山建业平西尊府", 23.0, 6, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0],
             ["郑州", "郑州建业天筑", 14.0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0],
             ["新乡", "辉县建业壹号城邦", 9.0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0],
             ["平顶山", "平顶山建业十八城", 7.0, 9, 0, 0, 0, 1, 0, 0, 0, 0, 7, 0],
             ["鹤壁", "鹤壁建业桂园", 7.0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0],
             ["洛阳", "洛阳建业科技城", 5.0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["新乡", "辉县建业春天里", 3.0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["三门峡", "三门峡建业联盟新城", 3.0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0],
             ["洛阳", "洛阳建业中州府 ", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], ["洛阳", "建业尊府", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["洛阳", "偃师建业森林半岛", 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["商丘", "商丘建业幸福里", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], ["商丘", "夏邑建业城", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["商丘", "商丘建业公园里", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["济源", "济源建业花园里", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["焦作", "武陟建业星天地", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["新乡", "长垣建业森林半岛上院", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["郑州", "新郑建业重点项目", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["鹤壁", "滑县建业壹号城邦", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["济源", "济源壹号城邦天玺", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["洛阳", "洛阳建业桂园", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], ["洛阳", "洛阳建业尊府", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["漯河", "漯河建业壹号城邦", 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["三门峡", "三门峡建业壹号城邦", 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0],
             ["商丘", "永城建业联盟新城", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["郑州", "郑州建业五龙新城", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["濮阳", "濮阳建业壹号城邦", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["安阳", "林州建业城", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["驻马店", "驻马店建业滨河珑府", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]],
            [["新乡", "新乡建业世和府", 260849.0, 12484, 10551, 7497, 286, 5580, 119, 0, 360, 0, 2403, 0],
             ["郑州", "郑州建业橙园", 210228.0, 18304, 16188, 9490, 34, 2454, 79, 5, 32, 0, 1898, 0],
             ["济源", "济源建业城", 150615.0, 13762, 11688, 5977, 4, 4587, 9, 1, 24, 0, 276, 0],
             ["洛阳", "洛阳建业定鼎府", 116535.0, 8568, 7331, 4987, 190, 3254, 73, 89, 9, 0, 503, 0],
             ["郑州", "郑州建业比华利庄园", 85744.0, 7542, 5968, 3942, 12, 1562, 6, 2, 44, 4, 637, 0],
             ["郑州", "郑州建业新筑", 83655.0, 8731, 6881, 4674, 5, 1723, 31, 0, 53, 0, 1033, 0],
             ["郑州", "登封建业嵩岳府", 79315.0, 6381, 5526, 2888, 8, 1844, 3, 0, 6, 0, 170, 0],
             ["新乡", "辉县建业共城东望", 69388.0, 8311, 7192, 5156, 44, 4226, 2, 50, 340, 0, 610, 0],
             ["驻马店", "驻马店建业世和府", 65822.0, 8168, 8152, 6327, 111, 5451, 156, 7, 318, 0, 4816, 0],
             ["郑州", "郑西建业联盟新城", 63593.0, 8184, 6816, 5006, 13, 3398, 261, 0, 116, 9, 542, 0],
             ["平顶山", "平顶山建业春天里", 54436.0, 5555, 4741, 3141, 1, 2350, 3, 0, 192, 0, 1027, 0],
             ["驻马店", "驻马店建业春天里", 47715.0, 4449, 4403, 3433, 378, 2114, 94, 201, 183, 0, 2826, 8],
             ["焦作", "焦作建业春天里", 43403.0, 7291, 7280, 5481, 7, 4996, 360, 0, 624, 3, 2343, 0],
             ["驻马店", "遂平建业城", 41996.0, 4010, 4000, 3375, 28, 3166, 11, 6, 1070, 0, 154, 0],
             ["三门峡", "三门峡建业新区森林半岛", 38991.0, 2658, 2206, 1508, 8, 766, 1, 0, 5, 0, 308, 0],
             ["漯河", "漯河建业花园里", 36524.0, 2637, 2631, 2300, 66, 1989, 2, 30, 192, 0, 390, 1],
             ["驻马店", "驻马店正阳建业城", 35974.0, 4260, 4256, 3409, 65, 3002, 144, 54, 519, 1, 2621, 1],
             ["焦作", "焦作建业世和府", 35433.0, 5356, 5344, 3715, 1, 3270, 16, 0, 226, 0, 1068, 0],
             ["驻马店", "汝南建业城", 32584.0, 1851, 1848, 1523, 380, 1308, 19, 6, 24, 0, 194, 0],
             ["信阳", "信阳建业城云熙府", 31148.0, 3350, 3335, 2272, 22, 1643, 112, 9, 126, 1, 1435, 0],
             ["漯河", "漯河建业云熙府", 27401.0, 3909, 3901, 3124, 40, 2615, 72, 6, 156, 1, 1198, 2],
             ["信阳", "息县建业尊府", 26325.0, 2825, 2801, 2091, 142, 1665, 21, 0, 236, 0, 504, 0],
             ["周口", "周口建业世悦府", 25858.0, 3139, 3134, 2339, 48, 1676, 4, 20, 89, 0, 451, 0],
             ["开封", "杞县建业一品花园里", 25638.0, 1323, 1316, 1022, 66, 765, 3, 5, 116, 0, 324, 0],
             ["周口", "西华建业箕城上院", 24284.0, 2611, 2600, 2165, 366, 1456, 2, 7, 403, 0, 295, 0],
             ["周口", "太康建业幸福里", 23996.0, 2228, 2203, 1613, 412, 1198, 9, 60, 25, 0, 281, 0],
             ["开封", "开封建业花园里", 23900.0, 1576, 1564, 1040, 2, 675, 2, 6, 138, 0, 684, 0],
             ["安阳", "安阳建业通和府", 22447.0, 2093, 2073, 1408, 7, 879, 39, 192, 161, 0, 1223, 91],
             ["信阳", "潢川建业黄国府", 21886.0, 3008, 3005, 1359, 62, 1232, 39, 0, 1, 0, 135, 0],
             ["漯河", "漯河建业桂园", 21844.0, 1421, 1413, 1208, 211, 976, 1, 24, 27, 0, 125, 0],
             ["驻马店", "西平建业春天里", 21534.0, 1368, 1333, 1026, 164, 821, 2, 33, 35, 0, 158, 8],
             ["郑州", "郑州建业云境", 21308.0, 2887, 2871, 2014, 1, 852, 12, 0, 10, 0, 853, 0],
             ["周口", "太康建业生态新城", 20375.0, 2468, 2448, 1698, 15, 1447, 3, 23, 3, 0, 962, 0],
             ["南阳", "邓州建业公园里", 19745.0, 2947, 2931, 1713, 206, 1260, 31, 211, 93, 0, 621, 31],
             ["周口", "鹿邑建业城", 19202.0, 1376, 1372, 928, 643, 626, 1, 8, 2, 0, 84, 0],
             ["周口", "周口建业世和府", 18962.0, 2645, 2634, 2005, 79, 1553, 6, 5, 17, 0, 418, 0],
             ["周口", "扶沟建业新城", 18835.0, 3047, 3039, 2243, 408, 1708, 6, 2, 157, 6, 485, 0],
             ["洛阳", "洛阳建业滨河珑府", 18750.0, 2179, 2167, 1538, 2, 581, 6, 0, 31, 0, 742, 0],
             ["郑州", "建业J18", 18089.0, 3095, 3085, 2110, 60, 993, 47, 1, 11, 0, 905, 0],
             ["信阳", "淮滨建业桂园", 17753.0, 1591, 1582, 1170, 180, 887, 4, 18, 104, 0, 311, 3],
             ["新乡", "卫辉建业春天里", 17485.0, 1465, 1459, 1017, 62, 742, 4, 0, 116, 0, 246, 0],
             ["鹤壁", "鹤壁建业臻悦汇", 17332.0, 1162, 1151, 851, 16, 546, 22, 6, 91, 11, 329, 0],
             ["商丘", "商丘建业橙园", 17295.0, 1468, 1447, 993, 26, 532, 5, 55, 153, 2, 1259, 1],
             ["安阳", "安阳建业世和府", 17208.0, 1394, 1369, 974, 13, 574, 19, 2, 28, 1, 439, 0],
             ["三门峡", "三门峡建业城", 17104.0, 878, 860, 607, 18, 363, 19, 8, 13, 0, 166, 0],
             ["驻马店", "驻马店建业尊府", 16797.0, 1393, 1383, 1177, 240, 864, 1, 0, 32, 0, 257, 0],
             ["驻马店", "平舆建业公园里", 16727.0, 2296, 2288, 1908, 161, 1532, 12, 31, 138, 0, 498, 0],
             ["商丘", "虞城建业山水湖城", 16068.0, 1670, 1660, 1202, 180, 795, 22, 50, 176, 0, 595, 0],
             ["周口", "商水建业阳城上院", 15190.0, 1472, 1469, 772, 138, 539, 5, 9, 50, 0, 102, 0],
             ["南阳", "南阳建业碧桂园龙悦城", 15091.0, 2136, 2073, 1429, 23, 655, 13, 104, 121, 0, 419, 0],
             ["平顶山", "汝州建业桂园", 14108.0, 1024, 1021, 726, 1, 481, 5, 24, 22, 0, 208, 0],
             ["商丘", "商丘建业十八城山水上境", 13441.0, 1238, 1216, 896, 2, 256, 6, 32, 60, 0, 468, 1],
             ["周口", "周口建业城", 12884.0, 1420, 1419, 998, 246, 742, 33, 2, 2, 0, 0, 0],
             ["信阳", "固始建业城", 12790.0, 1429, 1421, 1032, 18, 787, 72, 0, 74, 0, 553, 0],
             ["驻马店", "驻马店建业凯旋广场", 12779.0, 1643, 1628, 1235, 58, 937, 0, 52, 7, 0, 262, 0],
             ["周口", "周口建业山水湖城", 12137.0, 2625, 2620, 2108, 301, 1585, 287, 0, 41, 0, 322, 0],
             ["商丘", "商丘建业花园里", 11963.0, 1350, 1327, 990, 13, 249, 4, 39, 16, 0, 410, 9],
             ["周口", "周口建业大城小院", 11512.0, 1282, 1273, 943, 74, 646, 3, 2, 3, 0, 130, 1],
             ["焦作", "温县建业春天里", 10987.0, 1028, 1024, 520, 10, 445, 2, 4, 25, 0, 271, 1],
             ["新乡", "新乡建业春天里", 10581.0, 697, 680, 534, 20, 283, 6, 4, 100, 0, 401, 0],
             ["濮阳", "濮阳建业世和府", 10459.0, 797, 792, 622, 4, 253, 3, 3, 8, 0, 196, 0],
             ["信阳", "建业信阳府", 10436.0, 812, 809, 586, 11, 351, 1, 0, 4, 0, 91, 0],
             ["商丘", "商丘建业天筑", 9724.0, 728, 724, 524, 0, 216, 1, 0, 3, 8, 131, 0],
             ["南阳", "南阳建业新筑", 9424.0, 1069, 1052, 637, 85, 266, 2, 9, 15, 1, 338, 0],
             ["周口", "鹿邑明道城", 9098.0, 713, 712, 473, 174, 365, 16, 0, 3, 0, 100, 0],
             ["济源", "济源建业春天里", 8736.0, 635, 634, 428, 3, 184, 4, 0, 0, 0, 26, 0],
             ["新乡", "新乡建业花园里", 8673.0, 710, 690, 514, 9, 219, 4, 10, 4, 0, 227, 0],
             ["开封", "通许建业壹号城邦", 8591.0, 1020, 1017, 806, 14, 483, 5, 23, 10, 0, 281, 2],
             ["商丘", "睢县建业上和院", 8513.0, 744, 730, 516, 8, 317, 1, 17, 29, 8, 196, 0],
             ["鹤壁", "鹤壁建业世和府", 8059.0, 789, 768, 638, 4, 224, 0, 177, 6, 11, 274, 8],
             ["南阳", "南召建业城", 7968.0, 595, 591, 411, 69, 171, 0, 8, 21, 0, 192, 0],
             ["周口", "淮阳建业百城天地", 7333.0, 505, 424, 392, 9, 43, 0, 23, 0, 0, 6047, 0],
             ["三门峡", "三门峡建业尊府", 7077.0, 390, 386, 288, 14, 171, 0, 0, 2, 0, 58, 0],
             ["郑州", "郑州建业昌建公园里", 6775.0, 1321, 1314, 868, 4, 84, 0, 0, 0, 0, 75, 0],
             ["南阳", "西峡建业公园里", 6753.0, 645, 630, 500, 2, 127, 2, 1, 9, 1, 155, 0],
             ["漯河", "漯河建业丹江府", 6510.0, 529, 525, 445, 5, 316, 2, 1, 20, 0, 55, 0],
             ["周口", "项城建业城", 6466.0, 532, 518, 292, 38, 184, 11, 0, 12, 0, 173, 0],
             ["洛阳", "洛阳建业龙城东望", 5990.0, 529, 508, 392, 2, 84, 4, 1, 2, 0, 163, 0],
             ["开封", "开封建业半亩园", 5879.0, 898, 893, 632, 2, 510, 41, 0, 15, 0, 326, 0],
             ["商丘", "民权建业天明幸福里", 5747.0, 484, 442, 275, 6, 124, 1, 6, 4, 0, 160, 0],
             ["信阳", "固始建业未来城", 5677.0, 779, 777, 677, 189, 297, 19, 0, 157, 0, 213, 0],
             ["洛阳", "洛阳建业大城小院", 5645.0, 293, 293, 223, 2, 58, 5, 2, 0, 0, 49, 0],
             ["焦作", "博爱建业春天里", 5283.0, 657, 652, 498, 26, 388, 1, 0, 66, 0, 89, 0],
             ["南阳", "南阳建业十里湖山", 5238.0, 902, 880, 604, 22, 316, 2, 0, 5, 0, 326, 0],
             ["周口", "西华建业公园里", 5163.0, 750, 735, 574, 51, 441, 11, 3, 0, 0, 106, 0],
             ["漯河", "临颍建业森林半岛", 5162.0, 705, 699, 578, 41, 419, 0, 9, 0, 0, 739, 0],
             ["洛阳", "栾川建业鸾州府", 4089.0, 514, 512, 375, 3, 108, 0, 0, 0, 0, 109, 0],
             ["濮阳", "濮阳建业臻悦汇", 4030.0, 557, 549, 449, 0, 218, 0, 5, 3, 0, 135, 0],
             ["许昌", "许昌建业世和府", 4011.0, 424, 422, 322, 1, 101, 0, 0, 5, 0, 63, 0],
             ["南阳", "南阳建业公园里", 3881.0, 606, 505, 374, 13, 105, 0, 0, 3, 0, 116, 0],
             ["许昌", "许昌建业臻悦汇", 3729.0, 339, 337, 249, 0, 53, 0, 0, 3, 0, 39, 0],
             ["濮阳", "濮阳建业龙城", 3639.0, 330, 329, 190, 2, 117, 0, 0, 0, 0, 0, 0],
             ["许昌", "禹州建业春天里", 3418.0, 369, 367, 285, 0, 144, 0, 0, 24, 0, 51, 0],
             ["新乡", "新乡建业联盟新城", 3333.0, 338, 283, 242, 2, 26, 0, 0, 0, 0, 146, 0],
             ["许昌", "长葛建业桂园新苑", 2846.0, 316, 315, 244, 0, 80, 21, 0, 0, 0, 44, 0],
             ["许昌", "襄城建业百城天地", 2784.0, 223, 215, 151, 0, 34, 0, 0, 0, 0, 30, 0],
             ["许昌", "许昌建业心怡苑", 2683.0, 211, 204, 101, 9, 53, 0, 0, 1, 0, 1, 0],
             ["商丘", "商丘建业新筑", 2466.0, 198, 194, 140, 0, 15, 0, 0, 0, 0, 6, 0],
             ["驻马店", "平舆建业城", 2286.0, 340, 322, 281, 0, 150, 2, 1, 6, 0, 118, 0],
             ["许昌", "鄢陵建业生态新城", 2227.0, 119, 117, 98, 1, 24, 0, 0, 11, 6, 20, 0],
             ["郑州", "巩义建业世和府", 2208.0, 528, 524, 345, 0, 63, 0, 0, 0, 0, 60, 0],
             ["洛阳", "洛阳建业贰号城邦", 2180.0, 196, 191, 146, 4, 9, 0, 0, 1, 0, 11, 0],
             ["洛阳", "洛阳建业科技城", 1888.0, 293, 288, 195, 0, 12, 0, 0, 0, 0, 10, 0],
             ["洛阳", "伊川建业龙府", 1672.0, 169, 168, 124, 2, 12, 0, 0, 0, 0, 7, 0],
             ["开封", "兰考建业红天地", 1407.0, 153, 148, 113, 0, 36, 0, 2, 1, 0, 42, 0],
             ["郑州", "新郑建业天汇城", 1395.0, 466, 464, 362, 0, 63, 0, 0, 0, 0, 60, 0],
             ["许昌", "禹州建业大城小院", 1384.0, 161, 159, 118, 0, 54, 0, 0, 0, 0, 0, 0],
             ["安阳", "汤阴建业公园里", 1376.0, 137, 134, 104, 0, 21, 0, 0, 0, 0, 136, 0],
             ["安阳", "安阳建业城", 1353.0, 182, 181, 148, 0, 41, 1, 0, 0, 0, 4, 0],
             ["许昌", "长葛建业森林半岛", 1330.0, 142, 139, 78, 0, 24, 0, 0, 0, 0, 13, 0],
             ["商丘", "商丘建业信友未来城", 1190.0, 84, 84, 70, 0, 22, 4, 0, 0, 0, 21, 0],
             ["周口", "太康建业城", 1170.0, 352, 350, 225, 0, 20, 1, 0, 0, 0, 22, 0],
             ["平顶山", "平顶山建业光明府", 812.0, 70, 68, 57, 0, 8, 0, 0, 0, 0, 13, 0],
             ["驻马店", "遂平建业森林半岛", 807.0, 80, 75, 71, 0, 4, 0, 0, 0, 0, 4, 0],
             ["开封", "通许建业城", 787.0, 127, 120, 110, 10, 31, 0, 0, 0, 0, 36, 0],
             ["平顶山", "舞钢建业森林半岛", 783.0, 191, 117, 106, 0, 40, 0, 2, 2, 0, 65, 0],
             ["郑州", "郑州建业凯旋广场", 674.0, 113, 110, 88, 0, 9, 0, 0, 0, 0, 9, 0],
             ["安阳", "安阳建业君邻大院", 656.0, 58, 57, 29, 0, 15, 0, 0, 0, 0, 0, 0],
             ["郑州", "新密建业春天里", 554.0, 227, 224, 156, 0, 0, 0, 0, 0, 0, 3, 0],
             ["郑州", "郑州建业盛悦府", 521.0, 76, 73, 56, 0, 8, 3, 0, 0, 0, 13, 0],
             ["驻马店", "新蔡建业桂园", 497.0, 52, 51, 44, 0, 6, 0, 0, 0, 0, 1, 0],
             ["驻马店", "西平建业森林半岛", 449.0, 62, 55, 45, 4, 3, 0, 0, 0, 1, 9, 0],
             ["驻马店", "新蔡建百城天地", 357.0, 49, 47, 44, 1, 9, 0, 0, 0, 0, 4, 0],
             ["驻马店", "驻马店建业西湖庄园", 111.0, 37, 28, 25, 1, 4, 0, 0, 0, 0, 16, 0],
             ["郑州", "郑州建业尚悦广场", 92.0, 58, 57, 48, 0, 0, 0, 0, 0, 0, 0, 0],
             ["洛阳", "偃师建业森林半岛", 72.0, 20, 20, 11, 0, 0, 0, 0, 0, 0, 2, 0],
             ["平顶山", "平顶山建业平西尊府", 23.0, 6, 6, 5, 0, 1, 0, 0, 0, 0, 0, 0],
             ["郑州", "郑州建业天筑", 21.0, 11, 8, 8, 0, 0, 0, 0, 0, 0, 6, 0],
             ["平顶山", "平顶山建业十八城", 20.0, 21, 8, 8, 0, 1, 0, 0, 0, 8, 16, 0],
             ["新乡", "辉县建业壹号城邦", 17.0, 9, 6, 6, 0, 0, 0, 0, 0, 5, 7, 0],
             ["鹤壁", "滑县建业壹号城邦", 15.0, 11, 7, 7, 0, 0, 0, 0, 0, 7, 8, 0],
             ["洛阳", "建业尊府", 9.0, 9, 5, 5, 0, 0, 0, 0, 0, 0, 1, 0],
             ["商丘", "商丘建业公园里", 8.0, 9, 6, 6, 0, 0, 0, 0, 0, 0, 7, 0],
             ["新乡", "辉县建业春天里", 8.0, 6, 5, 5, 0, 0, 0, 0, 0, 0, 4, 0],
             ["鹤壁", "鹤壁建业桂园", 7.0, 8, 4, 4, 0, 0, 0, 0, 0, 2, 5, 0],
             ["商丘", "商丘建业幸福里", 5.0, 6, 3, 3, 0, 0, 0, 0, 0, 0, 3, 0],
             ["商丘", "夏邑建业城", 3.0, 4, 2, 2, 0, 0, 0, 0, 0, 0, 2, 0],
             ["郑州", "郑州建业五龙新城", 3.0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 0],
             ["三门峡", "三门峡建业联盟新城", 3.0, 3, 2, 2, 0, 0, 0, 0, 0, 0, 1, 0],
             ["济源", "济源建业花园里", 2.0, 2, 2, 2, 0, 0, 0, 0, 0, 0, 2, 0],
             ["新乡", "长垣建业森林半岛上院", 2.0, 5, 2, 2, 0, 0, 0, 0, 0, 0, 2, 0],
             ["安阳", "林州建业城", 1.0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0],
             ["洛阳", "洛阳建业中州府 ", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["焦作", "武陟建业星天地", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0],
             ["郑州", "新郑建业重点项目", 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["济源", "济源壹号城邦天玺", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0],
             ["洛阳", "洛阳建业桂园", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0], ["洛阳", "洛阳建业尊府", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0],
             ["漯河", "漯河建业壹号城邦", 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0],
             ["三门峡", "三门峡建业壹号城邦", 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0],
             ["商丘", "永城建业联盟新城", 0, 1, 0, 0, 0, 0, 0, 0, 0, 3, 1, 0],
             ["濮阳", 0, "濮阳建业壹号城邦", 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
             ["驻马店", "驻马店建业滨河珑府", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]])
    data = data_1.get('data2')
    sheet_names = ['前一日数据', '本月数据', '上线后所有']
    title = "测ss试.xlsx"
    head_1 = ['城市', '项目名称', '浏览量', '浏览人数', '新增用户', '新增获电', '推荐用户', '分享获电', '裂变获电',
              '扫码到访数', '全民经纪人注册数', '老业主注册数', '报备成功数', '报备到访数']
    headers = [head_1, head_1, head_1]
    rf.create_excel_file(data, sheet_names, title, headers, r'D:\elab-code\elab_mvp\resources\report_jian\测ss试.xlsx')
